@@ -40,7 +40,8 @@ class RESTclient():
         'Auth',
         'x-api-key',
         'Password',
-        'password'
+        'password',
+        'JWT'
     ]
 
     def __init__(self, hostname, **kwargs):
@@ -70,6 +71,10 @@ class RESTclient():
         if bearer_token:
             self.bearer_token = bearer_token
 
+        jwt = kwargs.get('jwt')
+        if jwt:
+            self.jwt = jwt
+
         certfile = kwargs.get('certfile')
         certpass = kwargs.get('certpass')
         self.certfile = certfile
@@ -101,6 +106,9 @@ class RESTclient():
         if hasattr(self, 'bearer_token'):
             headers['Authorization'] = f'Bearer {self.bearer_token}'
 
+        if hasattr(self, 'jwt'):
+            headers['Authorization'] = f'JWT {self.jwt}'
+
         return headers
 
     def get_arguments(self, endpoint, kwargs):
@@ -231,9 +239,7 @@ class RESTclient():
         """ return list of all retry_ methods found in self
         """
         return [
-            item
-                for item in dir(self)
-                     if callable(getattr(self, item)) and item.startswith('retry_')
+            item for item in dir(self) if callable(getattr(self, item)) and item.startswith('retry_')
         ]
 
     @staticmethod
